==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/architecture/statemachine/Event.java <==
package io.ciera.tool.sql.architecture.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.architecture.statemachine.StateMachine;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableCell;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableCellSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEvent;


public interface Event extends IModelInstance<Event,Sql> {

    // attributes
    public void setSm_name( String ref_sm_name ) throws XtumlException;
    public String getSm_name() throws XtumlException;
    public String getSm_package() throws XtumlException;
    public void setSm_package( String ref_sm_package ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setId( int m_id ) throws XtumlException;
    public int getId() throws XtumlException;
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException;
    public UniqueId getSMevt_ID() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR427_is_a_InvocableObject( InvocableObject inst ) {}
    public InvocableObject R427_is_a_InvocableObject() throws XtumlException;
    default public void setR4752_StateMachine( StateMachine inst ) {}
    public StateMachine R4752_StateMachine() throws XtumlException;
    default public void addR4756_TransitionTableCell( TransitionTableCell inst ) {}
    default public void removeR4756_TransitionTableCell( TransitionTableCell inst ) {}
    public TransitionTableCellSet R4756_TransitionTableCell() throws XtumlException;
    default public void setR4759_is_transformed_from_StateMachineEvent( StateMachineEvent inst ) {}
    public StateMachineEvent R4759_is_transformed_from_StateMachineEvent() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/statemachine/Event.java <==
package io.ciera.tool.sql.architecture.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.architecture.statemachine.StateMachine;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableCell;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableCellSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEvent;


public interface Event extends IModelInstance<Event,Sql> {

    // attributes
    public void setSm_name( String ref_sm_name ) throws XtumlException;
    public String getSm_name() throws XtumlException;
    public String getSm_package() throws XtumlException;
    public void setSm_package( String ref_sm_package ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setId( int m_id ) throws XtumlException;
    public int getId() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR427_is_a_InvocableObject( InvocableObject inst ) {}
    public InvocableObject R427_is_a_InvocableObject() throws XtumlException;
    default public void setR4752_StateMachine( StateMachine inst ) {}
    public StateMachine R4752_StateMachine() throws XtumlException;
    default public void addR4756_TransitionTableCell( TransitionTableCell inst ) {}
    default public void removeR4756_TransitionTableCell( TransitionTableCell inst ) {}
    public TransitionTableCellSet R4756_TransitionTableCell() throws XtumlException;
    default public void setR4759_StateMachineEvent( StateMachineEvent inst ) {}
    public StateMachineEvent R4759_StateMachineEvent() throws XtumlException;


}
